{% load i18n %}
<div class="card mb-3">
  <h5 class="card-header">{% trans "Summary" %}</h5>
  <div class="card-body">
    <ul>
	    {% for model_name, object_count in model_count %}
	    <li>{{ model_name|capfirst }}: {{ object_count }}</li>
	    {% endfor %}
	  </ul>
  </div>
</div>