{% load i18n admin_list admin_kubi_tags %}

<nav aria-label="...">
  {% if pagination_required %}
    <ul class="pagination pagination-sm">
      {% for i in page_range %}
        {% paginator_number cl i %}
      {% endfor %}
    </ul>
  {% endif %}
</nav>

<div class="row align-items-center">
  <div class="col">

    {% if cl.result_count > 0 %}
      <p class="list-info">
        <span class="info-counter text-muted small">
          {{ cl.result_count }}
          {% if cl.result_count == 1 %}
            {{ cl.opts.verbose_name }}
          {% else %}
            {{ cl.opts.verbose_name_plural }}
          {% endif %}
        </span>
        {% if show_all_url %}
          &nbsp;&nbsp;<a href="{{ show_all_url }}" class="showall">{% trans 'Show all' %}</a>
        {% endif %}
      </p>
    {% endif %}
  </div>

  <div class="col text-end paginator">
    {% if cl.formset and cl.result_count %}
      <input type="submit" name="_save" class="btn btn-primary" value="{% trans 'Save' %}"/>
    {% endif %}
  </div>
</div>