{% load i18n %}
<div class="toast" data-bs-toggle="toast" role="alert" aria-live="assertive" aria-atomic="true">
    <div class="toast-header">
      <svg class="bd-placeholder-img rounded me-2" width="20" height="20" xmlns="http://www.w3.org/2000/svg" aria-hidden="true" preserveAspectRatio="xMidYMid slice" focusable="false"><rect width="100%" height="100%" fill="#007aff"></rect></svg>
      <strong class="me-auto">{% if title == 'info' %}{% translate 'Success' %}{% else %}{{ title }}{% endif %}</strong>
      <small>{% if action_time %}{{ action_time }}{% else %}just now{% endif %}</small>
      <button type="button" class="btn-close" data-bs-dismiss="toast" aria-label="Close"></button>
    </div>
    <div class="toast-body">
      {{ message }}
    </div>
</div>