{% extends "admin/base_initial.html" %}
{% load i18n static %}

{% block bodyclass %}{{ block.super }} password-reset auth{% endblock %}

{% block title %}{% translate "Password reset complete" %}{% endblock %}

{% block initial-content %}

  <h1 class="h3 mb-3 fw-normal">{% translate 'Password reset complete' %}</h1>
  <p class="alert alert-success">
    {% translate "Your password has been set.  You may go ahead and log in now." %}
  </p>

  {% url 'admin:index' as admin_url %}
  {% if admin_url %}
    <br/>
    <p>
      <a class="link-body-emphasis" href="{{ admin_url }}">
        {% translate 'Go back to the login page.' %}
      </a>
    </p>
  {% endif %}
{% endblock %}
