{% load i18n %}
<div class="language_trigger_container d-none">
  <div class="language_container">
    <div id="language_trigger" data-label="{% trans 'Editing in' %}">
      <h4>{% trans 'Translation' %}</h4>
      <span class="handle"></span>
    </div>
  </div>
</div>