{% extends "registration/password_change_form.html" %}
{% load i18n admin_urls admin_kubi_tags %}

{% block title %}{% trans 'Password change successful' %}{% endblock %}

{% block content %}
  <h3 class="alert-heading">{% trans 'Password change successful' %}</h3>
  <p class="alert alert-block alert-success" id="info-password-change">
    {% trans 'Password was changed succesfully.' %}
  </p>

  <a href="{% url 'admin:index' %}" class="btn btn-secondary">
    <i class="fa fa-th-large"></i>
    {% trans 'Dashboard' %}
  </a>
  <a href="{% url 'admin:logout' %}" class="btn btn-danger">
    <i class="fa fa-sign-out-alt"></i>
    {% trans 'Log out' %}
  </a>
{% endblock %}
