{% load i18n static admin_urls admin_kubi_tags %}<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" dir="{{ LANGUAGE_BIDI|yesno:'rtl,ltr,auto' }}" data-bs-theme="auto">
<head>
<title>{% block title %}{% endblock %}</title>
<meta charset="utf-8">
{% block extrastyle %}{% endblock %}
<link rel="stylesheet" type="text/css" href="https://fonts.googleapis.com/css?family=Open+Sans:400,300" />
<link rel="stylesheet" type="text/css" href="{% static "admin/css/app.min.css" %}" />
{% if LANGUAGE_BIDI %}<link rel="stylesheet" href="{% block stylesheet_rtl %}{% static "admin/css/rtl.css" %}{% endblock %}">{% endif %}
{% block extrahead %}{% endblock %}
{% block responsive %}
    <meta name="viewport" content="user-scalable=no, width=device-width, initial-scale=1.0, maximum-scale=1.0">
    {% if LANGUAGE_BIDI %}<link rel="stylesheet" href="{% static "admin/css/responsive_rtl.css" %}">{% endif %}
{% endblock %}
{% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE" />{% endblock %}
<script type="text/javascript" src="{% static "js/color-mode.js" %}"></script>
<script defer src="https://use.fontawesome.com/releases/v5.1.0/js/all.js"></script>
</head>
{% load i18n %}

<body class="{% if is_popup %}popup {% endif %}{% block bodyclass %}{% endblock %}"
  data-admin-utc-offset="{% now "Z" %}">

  <svg xmlns="http://www.w3.org/2000/svg" style="display: none;">
    <symbol id="check2" viewBox="0 0 16 16">
      <path d="M13.854 3.646a.5.5 0 0 1 0 .708l-7 7a.5.5 0 0 1-.708 0l-3.5-3.5a.5.5 0 1 1 .708-.708L6.5 10.293l6.646-6.647a.5.5 0 0 1 .708 0z"/>
    </symbol>
    <symbol id="moon-stars-fill" viewBox="0 0 16 16">
      <path d="M6 .278a.768.768 0 0 1 .08.858 7.208 7.208 0 0 0-.878 3.46c0 4.021 3.278 7.277 7.318 7.277.527 0 1.04-.055 1.533-.16a.787.787 0 0 1 .81.316.733.733 0 0 1-.031.893A8.349 8.349 0 0 1 8.344 16C3.734 16 0 12.286 0 7.71 0 4.266 2.114 1.312 5.124.06A.752.752 0 0 1 6 .278z"/>
      <path d="M10.794 3.148a.217.217 0 0 1 .412 0l.387 1.162c.173.518.579.924 1.097 1.097l1.162.387a.217.217 0 0 1 0 .412l-1.162.387a1.734 1.734 0 0 0-1.097 1.097l-.387 1.162a.217.217 0 0 1-.412 0l-.387-1.162A1.734 1.734 0 0 0 9.31 6.593l-1.162-.387a.217.217 0 0 1 0-.412l1.162-.387a1.734 1.734 0 0 0 1.097-1.097l.387-1.162zM13.863.099a.145.145 0 0 1 .274 0l.258.774c.115.346.386.617.732.732l.774.258a.145.145 0 0 1 0 .274l-.774.258a1.156 1.156 0 0 0-.732.732l-.258.774a.145.145 0 0 1-.274 0l-.258-.774a1.156 1.156 0 0 0-.732-.732l-.774-.258a.145.145 0 0 1 0-.274l.774-.258c.346-.115.617-.386.732-.732L13.863.1z"/>
    </symbol>
    <symbol id="sun-fill" viewBox="0 0 16 16">
      <path d="M8 12a4 4 0 1 0 0-8 4 4 0 0 0 0 8zM8 0a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 0zm0 13a.5.5 0 0 1 .5.5v2a.5.5 0 0 1-1 0v-2A.5.5 0 0 1 8 13zm8-5a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2a.5.5 0 0 1 .5.5zM3 8a.5.5 0 0 1-.5.5h-2a.5.5 0 0 1 0-1h2A.5.5 0 0 1 3 8zm10.657-5.657a.5.5 0 0 1 0 .707l-1.414 1.415a.5.5 0 1 1-.707-.708l1.414-1.414a.5.5 0 0 1 .707 0zm-9.193 9.193a.5.5 0 0 1 0 .707L3.05 13.657a.5.5 0 0 1-.707-.707l1.414-1.414a.5.5 0 0 1 .707 0zm9.193 2.121a.5.5 0 0 1-.707 0l-1.414-1.414a.5.5 0 0 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .707zM4.464 4.465a.5.5 0 0 1-.707 0L2.343 3.05a.5.5 0 1 1 .707-.707l1.414 1.414a.5.5 0 0 1 0 .708z"/>
    </symbol>
  </svg>

  <div class="toast-container position-fixed top-0 end-0 p-3 pt-5">
  {% block messages %}
    {% if messages %}
      {% for message in messages %}
        {% include 'admin/message.html' with message=message|capfirst title=message.tags only %}
      {% endfor %}
    {% endif %}
  {% endblock messages %}
  {% block messages-extra %}{% endblock messages-extra %}
  </div>
<!-- Layout -->
<div class="{% block layout %}main-layout{% endblock %}">

  {% if user.is_authenticated %}
    {% include 'admin/menu.html' %}
  {% endif %}

  {% if not is_popup %}
    {% block breadcrumbs %}
      {% spaceless %}
        <nav class="breadcrumb">
          <span class="breadcrumb-icon"><i class="fa fa-th-large"></i></span>
          <span class="breadcrumb-item active">{% trans 'Dashboard' %}</span>
        </nav>
      {% endspaceless %}
    {% endblock %}
  {% endif %}

  <!-- Content -->
  <div id="content" class="{% block coltype %}colM{% endblock %} content">
    {% block object-tools %}{% endblock %}
    {% block content %}{% endblock %}
  </div>

  <!-- END Content -->
</div>
{% block footer %}{% endblock %}

<!-- END Layout -->
{% block js_footer_commons %}
  <script type="text/javascript" src="{% static "admin/js/vendor/bootstrap.bundle.min.js" %}"></script>
  <script type="text/javascript" src="{% static "admin/js/vendor/popper.min.js" %}"></script>
  <script type="text/javascript" src="{% static "js/jquery-3.3.1.min.js" %}"></script>
  <script type="text/javascript" src="{% static "js/force_jquery.js" %}"></script>
  <script type="text/javascript" src="{% static "admin/js/app.min.js" %}"></script>
{% endblock js_footer_commons %}

{% block js_footer %}{% endblock js_footer %}

</body>
</html>
