
.translation-tabs {

    margin-bottom: 15px;

    .tabs-handler {
        display: none;
    }

}

.language_trigger_container{
    position:fixed;
    left: 0px;
    bottom: 0px;
    z-index: 1000;
    right: 0px;
    height: 0px;
}

.language_container{
    position: absolute;
    bottom:0px;
    left:0px;
    right:0px;
    width:100%;
    padding: 0.65rem 1rem;
    background-color: $sidebar-bg-color;
    color: var(--#{$prefix}light);
    pointer-events: none;

    .handle {
        pointer-events: all;
    }

    h4{
        float: left;
        margin: 0px;
        margin-right: 1rem;
        line-height: 2.2rem;
        font-size: 1.2rem;
    }
}


@include media-breakpoint-up(lg) {

    .language_trigger_container {
        left: $sidebar-width;
    }

    .language_container {
        position: absolute;
        bottom: 0px;
        right: auto;
        left: 0px;
        width: 33%;
        padding: 10px 15px 10px 44px;
        background-color: var(--#{$prefix}tertiary-bg);
        color: var(--#{$prefix}tertiary-text);
        h4 {
            float: none;
        }
    }

    .language_trigger_container.bottom {
        position: absolute;
        bottom: 4px;
        left: 0px;
        right: 0px;
        width: 100%;
    }
}



@include media-breakpoint-up(xl) {
    .language_container {
        width: 25%;
    }
}