{% extends "admin/delete_selected_confirmation.html" %}
{% load i18n admin_urls admin_relation_modify %}


{% if not is_popup %}
  {% block breadcrumbs %}
    {% spaceless %}
      <nav class="breadcrumb">
        {% relation_admin_breadcrumbs %}
        <a class="breadcrumb-item" href="{% relation_admin_url 'changelist' %}">{{ opts.verbose_name_plural|capfirst }}</a>
        <span class="breadcrumb-item active">{% trans 'Delete multiple objects' %}</span>
      </nav>
    {% endspaceless %}
  {% endblock %}
{% endif %}
