{% extends "admin/change_list.html" %}

{% block object-tools-items %}
  <div class="btn-group">
    {% include "admin/import_export/includes/change_list_import_item.html" %}
    {% include "admin/import_export/includes/change_list_export_item.html" %}
   </div>
  {{ block.super }}
{% endblock %}
