{% extends "admin/import_export/base.html" %}
{% load i18n admin_urls import_export_tags %}

{% block breadcrumbs_last %}
  <span class="breadcrumb-item active">{% trans "Export" %}</span>
{% endblock %}

{% block submit_buttons_bottom %}
<div class="form-actions row">
  <div class="col-xs-12 text-end save-options-box">
    <a href="../" class="btn btn-default">{% trans 'Done' %}</a>
    <input type="submit" class="btn btn-primary" value="{% trans 'Submit' %}"/>
  </div>
</div>
{% endblock %}

